'****************************************************************
'*  Name    : FT800.INC                                         *
'*  Author  : Bobby Garrett                                     *
'*  Notice  : Copyright (c) 2014                                *
'*          : All Rights Reserved                               *
'*  Date    : 06/06/2014                                        *
'*  Version : 1.1                                               *
'*  Notes   : Converted from FTDI FT800.h                       *
'*          :                                                   *
'****************************************************************

' V1.2, Changed Repeat to FT_Repeat as Repeat is a command
'       also changed FTPoints to Points as it is not a reserved word in PDS
' V1.1, changed COLOR to COLOUR

'*************** D E C L A R A T I O N S ************************

Symbol FT_DL_SIZE          = (8*1024)   '8KB Display List buffer size
Symbol FT_CMD_FIFO_SIZE    = (4*1024)   '4KB coprocessor Fifo size
Symbol FT_CMD_SIZE         = (4)        '4 Byte per coprocessor command of EVE

'Symbol FT800_VERSION         "1.9.0"    ??

' Refer to the FT800 Datasheet

' FT800 Memory Map Addresses
Symbol RAM_CMD             = 0x108000   'UL
Symbol RAM_DL              = 0x100000   'UL
Symbol RAM_G               = 0x000000   'UL
Symbol RAM_PAL             = 0x102000   'UL
Symbol RAM_REG             = 0x102400   'UL

' FT800 Register Addresses
Symbol REG_CLOCK           = 0x102408   'UL
Symbol REG_CMD_DL          = 0x1024ec   'UL
Symbol REG_CMD_READ        = 0x1024e4   'UL
Symbol REG_CMD_WRITE       = 0x1024e8   'UL
Symbol REG_CPURESET        = 0x10241c   'UL
Symbol REG_CSPREAD         = 0x102464   'UL
Symbol REG_DITHER          = 0x10245c   'UL
Symbol REG_DLSWAP          = 0x102450   'UL
Symbol REG_FRAMES          = 0x102404   'UL
Symbol REG_FREQUENCY       = 0x10240c   'UL
Symbol REG_GPIO            = 0x102490   'UL
Symbol REG_GPIO_DIR        = 0x10248c   'UL
Symbol REG_HCYCLE          = 0x102428   'UL
Symbol REG_HOFFSET         = 0x10242c   'UL
Symbol REG_HSIZE           = 0x102430   'UL
Symbol REG_HSYNC0          = 0x102434   'UL
Symbol REG_HSYNC1          = 0x102438   'UL
Symbol REG_ID              = 0x102400   'UL
Symbol REG_INT_EN          = 0x10249c   'UL
Symbol REG_INT_FLAGS       = 0x102498   'UL
Symbol REG_INT_MASK        = 0x1024a0   'UL
Symbol REG_MACRO_0         = 0x1024c8   'UL
Symbol REG_MACRO_1         = 0x1024cc   'UL
Symbol REG_OUTBITS         = 0x102458   'UL
Symbol REG_PCLK            = 0x10246c   'UL
Symbol REG_PCLK_POL        = 0x102468   'UL
Symbol REG_PLAY            = 0x102488   'UL
Symbol REG_PLAYBACK_FORMAT = 0x1024b4   'UL
Symbol REG_PLAYBACK_FREQ   = 0x1024b0   'UL
Symbol REG_PLAYBACK_LENGTH = 0x1024a8   'UL
Symbol REG_PLAYBACK_LOOP   = 0x1024b8   'UL
Symbol REG_PLAYBACK_PLAY   = 0x1024bc   'UL
Symbol REG_PLAYBACK_READPTR = 0x1024ac  'UL
Symbol REG_PLAYBACK_START  = 0x1024a4   'UL
Symbol REG_PWM_DUTY        = 0x1024c4   'UL
Symbol REG_PWM_HZ          = 0x1024c0   'UL
Symbol REG_RENDERMODE      = 0x102410   'UL
Symbol REG_ROTATE          = 0x102454   'UL
Symbol REG_SNAPSHOT        = 0x102418   'UL
Symbol REG_SNAPY           = 0x102414   'UL
Symbol REG_SOUND           = 0x102484   'UL
Symbol REG_SWIZZLE         = 0x102460   'UL
Symbol REG_TAG             = 0x102478   'UL
Symbol REG_TAG_X           = 0x102470   'UL
Symbol REG_TAG_Y           = 0x102474   'UL
Symbol REG_TAP_CRC         = 0x102420   'UL
Symbol REG_TAP_MASK        = 0x102424   'UL
Symbol REG_TOUCH_ADC_MODE  = 0x1024f4   'UL
Symbol REG_TOUCH_CHARGE    = 0x1024f8   'UL
Symbol REG_TOUCH_DIRECT_XY = 0x102574   'UL
Symbol REG_TOUCH_DIRECT_Z1Z2 = 0x102578 'UL
Symbol REG_TOUCH_MODE      = 0x1024f0   'UL
Symbol REG_TOUCH_OVERSAMPLE = 0x102500  'UL
Symbol REG_TOUCH_RAW_XY    = 0x102508   'UL
Symbol REG_TOUCH_RZ        = 0x10250c   'UL
Symbol REG_TOUCH_RZTHRESH  = 0x102504   'UL
Symbol REG_TOUCH_SCREEN_XY = 0x102510   'UL
Symbol REG_TOUCH_SETTLE    = 0x1024fc   'UL
Symbol REG_TOUCH_TAG       = 0x102518   'UL
Symbol REG_TOUCH_TAG_XY    = 0x102514   'UL
Symbol REG_TOUCH_TRANSFORM_A = 0x10251c 'UL
Symbol REG_TOUCH_TRANSFORM_B = 0x102520 'UL
Symbol REG_TOUCH_TRANSFORM_C = 0x102524 'UL
Symbol REG_TOUCH_TRANSFORM_D = 0x102528 'UL
Symbol REG_TOUCH_TRANSFORM_E = 0x10252c 'UL
Symbol REG_TOUCH_TRANSFORM_F = 0x102530 'UL
Symbol REG_TRACKER         = 0x109000   'UL
Symbol REG_VCYCLE          = 0x10243c   'UL
Symbol REG_VOFFSET         = 0x102440   'UL
Symbol REG_VOL_PB          = 0x10247c   'UL
Symbol REG_VOL_SOUND       = 0x102480   'UL
Symbol REG_VSIZE           = 0x102444   'UL
Symbol REG_VSYNC0          = 0x102448   'UL
Symbol REG_VSYNC1          = 0x10244c   'UL

' Graphics Engine Commands
' Refer to the FT800 Programmers Guide
Symbol CMDBUF_SIZE         = 4096       'UL
Symbol CMD_APPEND          = 0xffffff1e 'UL
Symbol CMD_BGCOLOR         = 0xffffff09 'UL
Symbol CMD_BUTTON          = 0xffffff0d 'UL
Symbol CMD_CALIBRATE       = 0xffffff15 'UL
Symbol CMD_CLOCK           = 0xffffff14 'UL
Symbol CMD_COLDSTART       = 0xffffff32 'UL
Symbol CMD_DIAL            = 0xffffff2d 'UL
Symbol CMD_DLSTART         = 0xffffff00 'UL
Symbol CMD_FGCOLOR         = 0xffffff0a 'UL
Symbol CMD_GAUGE           = 0xffffff13 'UL
Symbol CMD_GETMATRIX       = 0xffffff33 'UL
Symbol CMD_GETPTR          = 0xffffff23 'UL
Symbol CMD_GRADCOLOR       = 0xffffff34 'UL
Symbol CMD_GRADIENT        = 0xffffff0b 'UL
Symbol CMD_INFLATE         = 0xffffff22 'UL
Symbol CMD_INTERRUPT       = 0xffffff02 'UL
Symbol CMD_KEYS            = 0xffffff0e 'UL
Symbol CMD_LOADIDENTITY    = 0xffffff26 'UL
Symbol CMD_LOADIMAGE       = 0xffffff24 'UL
Symbol CMD_LOGO            = 0xffffff31 'UL
Symbol CMD_MEMCPY          = 0xffffff1d 'UL
Symbol CMD_MEMCRC          = 0xffffff18 'UL
Symbol CMD_MEMSET          = 0xffffff1b 'UL
Symbol CMD_MEMWRITE        = 0xffffff1a 'UL
Symbol CMD_MEMZERO         = 0xffffff1c 'UL
Symbol CMD_NUMBER          = 0xffffff2e 'UL
Symbol CMD_PROGRESS        = 0xffffff0f 'UL
Symbol CMD_REGREAD         = 0xffffff19 'UL
Symbol CMD_ROTATE          = 0xffffff29 'UL
Symbol CMD_SCALE           = 0xffffff28 'UL
Symbol CMD_SCREENSAVER     = 0xffffff2f 'UL
Symbol CMD_SCROLLBAR       = 0xffffff11 'UL
Symbol CMD_SETFONT         = 0xffffff2b 'UL
Symbol CMD_SETMATRIX       = 0xffffff2a 'UL
Symbol CMD_SKETCH          = 0xffffff30 'UL
Symbol CMD_SLIDER          = 0xffffff10 'UL
Symbol CMD_SNAPSHOT        = 0xffffff1f 'UL
Symbol CMD_SPINNER         = 0xffffff16 'UL
Symbol CMD_STOP            = 0xffffff17 'UL
Symbol CMD_SWAP            = 0xffffff01 'UL
Symbol CMD_TEXT            = 0xffffff0c 'UL
Symbol CMD_TOGGLE          = 0xffffff12 'UL
Symbol CMD_TRACK           = 0xffffff2c 'UL
Symbol CMD_TRANSLATE       = 0xffffff27 'UL

' Display list commands to be embedded in Graphics Processor
Symbol DL_ALPHA_FUNC       = 0x09000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_HANDLE    = 0x05000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_LAYOUT    = 0x07000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_SIZE      = 0x08000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_SOURCE    = 0x01000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_TFORM_A   = 0x15000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_TFORM_B   = 0x16000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_TFORM_C   = 0x17000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_TFORM_D   = 0x18000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_TFORM_E   = 0x19000000 'UL ' requires Or'd arguments
Symbol DL_BITMAP_TFORM_F   = 0x1A000000 'UL ' requires Or'd arguments
Symbol DL_BLEND_FUNC       = 0x0B000000 'UL ' requires Or'd arguments
Symbol DL_BEGIN            = 0x1F000000 'UL ' requires Or'd arguments
Symbol DL_CALL             = 0x1D000000 'UL ' requires Or'd arguments
Symbol DL_CLEAR            = 0x26000000 'UL ' requires Or'd arguments
Symbol DL_CELL             = 0x06000000 'UL ' requires Or'd arguments
Symbol DL_CLEAR_RGB        = 0x02000000 'UL ' requires Or'd arguments
Symbol DL_CLEAR_STENCIL    = 0x11000000 'UL ' requires Or'd arguments
Symbol DL_CLEAR_TAG        = 0x12000000 'UL ' requires Or'd arguments
Symbol DL_COLOUR_A         = 0x0F000000 'UL ' requires Or'd arguments
Symbol DL_COLOUR_MASK      = 0x20000000 'UL ' requires Or'd arguments
Symbol DL_COLOUR_RGB       = 0x04000000 'UL ' requires Or'd arguments
Symbol DL_DISPLAY          = 0x00000000 'UL
Symbol DL_END              = 0x21000000 'UL
Symbol DL_JUMP             = 0x1E000000 'UL ' requires Or'd arguments
Symbol DL_LINE_WIDTH       = 0x0E000000 'UL ' requires Or'd arguments
Symbol DL_MACRO            = 0x25000000 'UL ' requires Or'd arguments
Symbol DL_POINT_SIZE       = 0x0D000000 'UL ' requires Or'd arguments
Symbol DL_RESTORE_CONTEXT  = 0x23000000 'UL
Symbol DL_RETURN           = 0x24000000 'UL
Symbol DL_SAVE_CONTEXT     = 0x22000000 'UL
Symbol DL_SCISSOR_SIZE     = 0x1C000000 'UL ' requires Or'd arguments
Symbol DL_SCISSOR_XY       = 0x1B000000 'UL ' requires Or'd arguments
Symbol DL_STENCIL_FUNC     = 0x0A000000 'UL ' requires Or'd arguments
Symbol DL_STENCIL_MASK     = 0x13000000 'UL ' requires Or'd arguments
Symbol DL_STENCIL_OP       = 0x0C000000 'UL ' requires Or'd arguments
Symbol DL_TAG              = 0x03000000 'UL ' requires Or'd arguments
Symbol DL_TAG_MASK         = 0x14000000 'UL ' requires Or'd arguments
Symbol DL_VERTEX2F         = 0x40000000 'UL ' requires Or'd arguments
Symbol DL_VERTEX2II        = 0x02000000 'UL ' requires Or'd arguments

' Command and register value options
Symbol CLR_COL             = 0x4
Symbol CLR_STN             = 0x2
Symbol CLR_TAG             = 0x1
Symbol DECR                = 4          'UL
Symbol DECR_WRAP           = 7          'UL
Symbol DLSWAP_DONE         = 0          'UL
Symbol DLSWAP_FRAME        = 2          'UL
Symbol DLSWAP_LINE         = 1          'UL
Symbol DST_ALPHA           = 3          'UL
Symbol EDGE_STRIP_A        = 7          'UL
Symbol EDGE_STRIP_B        = 8          'UL
Symbol EDGE_STRIP_L        = 6          'UL
Symbol EDGE_STRIP_R        = 5          'UL
Symbol EQUAL               = 5          'UL
Symbol GEQUAL              = 4          'UL
Symbol GREATER             = 3          'UL
Symbol INCR                = 3          'UL
Symbol INCR_WRAP           = 6          'UL
Symbol INT_CMDEMPTY        = 32         'UL
Symbol INT_CMDFLAG         = 64         'UL
Symbol INT_CONVCOMPLETE    = 128        'UL
Symbol INT_PLAYBACK        = 16         'UL
Symbol INT_SOUND           = 8          'UL
Symbol INT_SWAP            = 1          'UL
Symbol INT_TAG             = 4          'UL
Symbol INT_TOUCH           = 2          'UL
Symbol INVERT              = 5          'UL
Symbol KEEP                = 1          'UL
Symbol L1                  = 1          'UL
Symbol L4                  = 2          'UL
Symbol L8                  = 3          'UL
Symbol LEQUAL              = 2          'UL
Symbol LESS                = 1          'UL
Symbol LINEAR_SAMPLES      = 0          'UL
Symbol LINES               = 3          'UL
Symbol LINE_STRIP          = 4          'UL
Symbol NEAREST             = 0          'UL
Symbol NEVER               = 0          'UL
Symbol NOTEQUAL            = 6          'UL
Symbol ONE                 = 1          'UL
Symbol ONE_MINUS_DST_ALPHA = 5          'UL
Symbol ONE_MINUS_SRC_ALPHA = 4          'UL
Symbol OPT_CENTER          = 1536       'UL    // 0x6000
Symbol OPT_CENTERX         = 512        'UL    // 0x0200
Symbol OPT_CENTERY         = 1024       'UL    // 0x0400
Symbol OPT_FLAT            = 256        'UL    // 0x0100
Symbol OPT_MONO            = 1          'UL
Symbol OPT_NOBACK          = 4096       'UL    // 0x1000
Symbol OPT_NODL            = 2          'UL
Symbol OPT_NOHANDS         = 49152      'UL    // 0xC168
Symbol OPT_NOHM            = 16384      'UL    // 0x4000
Symbol OPT_NOPOINTER       = 16384      'UL    // 0x4000
Symbol OPT_NOSECS          = 32768      'UL    // 0x8000
Symbol OPT_NOTICKS         = 8192       'UL    // 0x2000
Symbol OPT_RIGHTX          = 2048       'UL    // 0x0800
Symbol OPT_SIGNED          = 256        'UL    // 0x0100
Symbol PALETTED            = 8          'UL
Symbol PLAYCOLOR           = 0x00a0a080
Symbol POINTS              = 2          'UL 
Symbol RECTS               = 9          'UL
Symbol FT_Repeat           = 1          'UL
Symbol REPLACE             = 2          'UL
Symbol RGB332              = 4          'UL
Symbol RGB565              = 7          'UL
Symbol SRC_ALPHA           = 2          'UL
Symbol TEXT8X8             = 9          'UL
Symbol TEXTVGA             = 10         'UL
Symbol TOUCHMODE_CONTINUOUS = 3         'UL
Symbol TOUCHMODE_FRAME     = 2          'UL
Symbol TOUCHMODE_OFF       = 0          'UL
Symbol TOUCHMODE_ONESHOT   = 1          'UL
Symbol ULAW_SAMPLES        = 1          'UL
Symbol ZERO                = 0          'UL

' Useful Macros
'Symbol RGB(r, g, b)         ((((r) << 16) | (g) << 8) | (b))
'Symbol SQ(v)                ((v) * (v))
'Symbol MIN(x,y)             ((x) > (y) ? (y) : (x))
'Symbol MAX(x,y)             ((x) > (y) ? (x) : (y))
'Symbol NOTE(n, sharp)       (((n) - 'C') + ((sharp) * 128))
'Symbol F16(s)               (((s) * 65536))
'Symbol INVALID_TOUCH_XY     0x8000
'Symbol Abs(x)               ((x) > (0) ? (x) : (-x))

